@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver;
 # ABSTRACT: Perl implementation of the Neo4j Driver API
-$Neo4j::Driver::VERSION = '0.12';
+$Neo4j::Driver::VERSION = '0.13';
 
 use Carp qw(croak);
 use Module::Load;
@@ -14,10 +14,25 @@ use URI 1.25;
 use Neo4j::Driver::Transport::HTTP;
 use Neo4j::Driver::Session;
 
+# The following packages are never used directly anywhere. We mention them
+# here so that a simple `use Neo4j::Driver;` will make them available.
+use Neo4j::Driver::Type::Node;
+use Neo4j::Driver::Type::Relationship;
+use Neo4j::Driver::Type::Path;
+use Neo4j::Driver::Type::Point;
+use Neo4j::Driver::Type::Temporal;
+
 
 my %NEO4J_DEFAULT_PORT = (
 	bolt => 7687,
 	http => 7474,
+	https => 7473,
+);
+
+my %DEFAULTS = (
+	die_on_error => 1,
+	http_timeout => 6,  # seconds
+	ca_file => undef,
 );
 
 
@@ -33,7 +48,7 @@ sub new {
 			croak "Only the 'http' URI scheme is supported [$uri] (you may need to install the Neo4j::Bolt module)" if $@;
 		}
 		else {
-			croak "Only the 'http' URI scheme is supported [$uri]" if $uri->scheme ne 'http';
+			croak "Only the 'http' URI scheme is supported [$uri]" if $uri->scheme !~ m/^https?$/;
 		}
 		
 		croak "Hostname is required [$uri]" if ! $uri->host;
@@ -43,12 +58,7 @@ sub new {
 	}
 	$uri->port( $NEO4J_DEFAULT_PORT{ $uri->scheme } ) if ! $uri->_port;
 	
-	my @defaults = (
-		die_on_error => 1,
-		http_timeout => 6,  # seconds
-	);
-	
-	return bless { uri => $uri, @defaults }, $class;
+	return bless { uri => $uri, %DEFAULTS }, $class;
 }
 
 
@@ -65,6 +75,15 @@ sub basic_auth {
 }
 
 
+sub config {
+	my ($self, $key, $value) = @_;
+	
+	croak "Config option '$key' unsupported" unless grep m/^$key$/, keys %DEFAULTS;
+	$self->{$key} = $value;
+	return $self;
+}
+
+
 sub session {
 	my ($self) = @_;
 	
@@ -99,7 +118,7 @@ Neo4j::Driver - Perl implementation of the Neo4j Driver API
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -111,7 +130,7 @@ version 0.12
    my $query = 'MATCH (a:Person)-[:KNOWS]->(f) '
              . 'WHERE a.name = {name} RETURN f.name';
    my $records = $driver->session->run($query, name => shift)->list;
-   forach my $record ( @$records ) {
+   foreach my $record ( @$records ) {
      say $record->get('f.name');
    }
  }
@@ -121,11 +140,9 @@ version 0.12
 =head1 DESCRIPTION
 
 This is an unofficial Perl implementation of the
-L<Neo4j Driver API|https://neo4j.com/docs/developer-manual/current/drivers/#driver-use-the-driver>.
-It enables interacting with a Neo4j database server using more or
-less the same classes and method calls as the official Neo4j drivers
-do. Responses from the Neo4j server are passed through to the client
-as-is.
+L<Neo4j Driver API|https://neo4j.com/docs/driver-manual/current/>.
+It enables interacting with a Neo4j database server using the
+same classes and method calls as the official Neo4j drivers do.
 
 This driver extends the uniformity across languages, which is a
 stated goal of the Neo4j Driver API, to Perl. The downside is that
@@ -134,8 +151,19 @@ existing L<REST::Neo4p> module does. Nor does it offer any L<DBI>
 integration. However, it avoids the legacy C<cypher> endpoint,
 assuring compatibility with future Neo4j versions.
 
-B<This software has pre-release quality. There is no schedule for
-further development. The interface is not yet stable.>
+B<As of version 0.13, the interface of this software may be
+considered stable.>
+
+However, bugs may still exist. Also, experimental features may be
+changed or deprecated at any time. If you find yourself reliant on
+an experimental feature, please file a new issue requesting that it
+be made stable.
+
+There is an ongoing effort to clean up the experimental features.
+For each of them, the goal is to eventually either declare it stable
+or deprecate it. There is also ongoing work to further improve
+general stability and reliability of this software. However, there
+is no schedule for the completion of these efforts.
 
 =head1 METHODS
 
@@ -165,8 +193,7 @@ Only the C<http> URI scheme is currently supported.
 If a part of the URI or even the entire URI is missing, suitable
 default values will be substituted. In particular, the host name
 C<localhost> will be used as default, along with the default port
-of the selected protocol. The default protocol might change to
-C<https> in future.
+of the selected protocol.
 
  # all of these are semantically equal
  my $driver = Neo4j::Driver->new;
@@ -209,13 +236,37 @@ incompatibilities with other "experimental" features of this driver,
 and parts of the documentation still assume that HTTP is the only
 option.
 
+TLS encryption is disabled in early versions of L<Neo4j::Bolt>.
+If you need remote access, consider using HTTPS instead of Bolt.
+
+=head2 HTTPS support
+
+ my $driver = Neo4j::Driver->new('https://localhost');
+ $driver->config(ca_file => 'neo4j/certificates/neo4j.cert');
+
+Using HTTPS will result in an encrypted connection. In order to rule
+out a man-in-the-middle attack, the server's certificate must be
+verified. By default, this driver may be expected to use operating
+system default root certificates (not really tested yet). This
+will fail unless your Neo4j installation uses a key pair that is
+trusted and verifiable through the global CA infrastructure. For
+self-signed certificates (such as those automatically provided by
+some Neo4j versions), you need to specify the location of a local
+copy of the server certificate. The driver config option C<ca_file>
+may be used for this; it corresponds to C<SSL_ca_file> in
+L<LWP::UserAgent> and L<IO::Socket::SSL>.
+
+See also the
+L<Neo4j Operations Manual|https://neo4j.com/docs/operations-manual/current/security/>
+for details on Neo4j network security.
+
 =head2 Close method
 
  $driver->close;  # no-op
 
-This driver does not support persistent connections at present. All
-connections are closed automatically. There is no need for explicit
-calls to C<close> at this time.
+All resources opened by this driver are closed automatically once
+they are no longer required. Explicit calls to C<close()> are neither
+required nor useful.
 
 =head2 HTTP Timeout
 
@@ -273,21 +324,30 @@ L<Try::Tiny> or similar instead.
 
 =head1 ENVIRONMENT
 
-This software currently targets Neo4j versions 2.3, 3.x and 4.x. The
-latter doesn't exist yet, but is expected to continue support for the
-Transactional HTTP endpoint that this driver uses (as opposed to the
-Legacy Cypher HTTP endpoint, which is expected to be discontinued
-starting in Neo4j 4.0 along with direct REST access to the graph
-entities).
+This software currently targets Neo4j versions 2.3, 3.x and 4.x.
 
 This software requires at least Perl 5.10, though you should consider
 using Perl 5.16 or newer if you can.
 
+=head1 PERFORMANCE
+
+Preliminary testing seems to indicate the two major bottlenecks are
+the HTTP transport to and from the Neo4j server, and the JSON
+parsing. Switching to the experimental Bolt protocol support may well
+increase the speed tenfold. You are encouraged to run your own tests
+for your specific application.
+
 =head1 DIAGNOSTICS
 
 Neo4j::Driver currently dies as soon as an error condition is
 discovered. Use C<eval>, L<Try::Tiny> or similar to catch this.
 
+Warnings are given when deprecated or ambiguous method calls are used.
+These warnings may be disabled if desired.
+
+ no warnings 'deprecated';
+ no warnings 'ambiguous';
+
 =head1 BUGS
 
 See the F<TODO> document and Github for known issues and planned
@@ -305,8 +365,8 @@ driver at present.
 =head1 SEE ALSO
 
 L<Neo4j::Driver::Session>,
-L<Neo4j Developer Manual: Drivers|https://neo4j.com/docs/developer-manual/current/drivers/#driver-use-the-driver>,
-L<Neo4j Transactional Cypher HTTP API|https://neo4j.com/docs/developer-manual/current/http-api/>,
+L<Neo4j Drivers Manual|https://neo4j.com/docs/driver-manual/current/>,
+L<Neo4j HTTP API Docs|https://neo4j.com/docs/http-api/current/>,
 L<REST::Neo4p>
 
 =head1 AUTHOR
